@@ -14,7 +14,7 @@ from StringIO import StringIO as p_StringO
 from cStringIO import OutputType as c_StringO
 import traceback
 import datetime
-from devicewrapper.android import device, ExpectException
+from uiautomatorplug.android import device, ExpectException
 
 log = logging.getLogger(__name__)
 '''global log instance'''
@@ -423,4 +423,4 @@ class FileOutputPlugin(nose.plugins.Plugin):
 
         self.result_properties.clear()
         self.result_properties.update({'name':case_dir_name, 'result':'pass', 'start_at':str(self.conf.case_start_time), 'end_at': str(datetime.datetime.now())})
-        writeResultToFile(self.result_file, self.result_properties)
\ No newline at end of file
+        writeResultToFile(self.result_file, self.result_properties)
